/*
 * Interface wrapper code.
 *
 * Generated by SIP 4.19.3
 */

#include "sipAPIKConfigGui.h"

#include <kconfigskeleton.h>

#include <qstring.h>
#include <qobject.h>
#include <kconfigskeleton.h>
#include <kconfigskeleton.h>
#include <qfont.h>
#include <kconfigskeleton.h>
#include <kconfigskeleton.h>
#include <qcolor.h>
#include <kcoreconfigskeleton.h>
#include <qlist.h>
#include <kconfig.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qlist.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qstringlist.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qdatetime.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qsize.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qpoint.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qrect.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qvariant.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <kcoreconfigskeleton.h>
#include <qmetaobject.h>
#include <qcoreevent.h>
#include <qcoreevent.h>
#include <qcoreevent.h>
#include <qlist.h>
#include <qbytearray.h>
#include <qlist.h>
#include <qnamespace.h>
#include <qthread.h>
#include <qnamespace.h>
#include <qregexp.h>
#include <qregularexpression.h>
#include <qobjectdefs.h>


class sipKConfigSkeleton : public  ::KConfigSkeleton
{
public:
    sipKConfigSkeleton(const  ::QString&, ::QObject*);
    virtual ~sipKConfigSkeleton();

    int qt_metacall(QMetaObject::Call,int,void **);
    void *qt_metacast(const char *);
    const QMetaObject *metaObject() const;

    /*
     * There is a public method for every protected method visible from
     * this class.
     */
     ::QObject* sipProtect_sender() const;
    int sipProtect_receivers(const char*) const;
    void sipProtectVirt_timerEvent(bool, ::QTimerEvent*);
    void sipProtectVirt_childEvent(bool, ::QChildEvent*);
    void sipProtectVirt_customEvent(bool, ::QEvent*);
    void sipProtectVirt_connectNotify(bool,const  ::QMetaMethod&);
    void sipProtectVirt_disconnectNotify(bool,const  ::QMetaMethod&);
    int sipProtect_senderSignalIndex() const;
    bool sipProtect_isSignalConnected(const  ::QMetaMethod&) const;
    bool sipProtectVirt_usrUseDefaults(bool,bool);
    void sipProtectVirt_usrSetDefaults(bool);
    void sipProtectVirt_usrRead(bool);
    bool sipProtectVirt_usrSave(bool);
    void sipProtectVirt_usrReadConfig(bool);
    bool sipProtectVirt_usrWriteConfig(bool);

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const  ::QMetaMethod&);
    void connectNotify(const  ::QMetaMethod&);
    void customEvent( ::QEvent*);
    void childEvent( ::QChildEvent*);
    void timerEvent( ::QTimerEvent*);
    bool eventFilter( ::QObject*, ::QEvent*);
    bool event( ::QEvent*);
    void setDefaults();
    bool useDefaults(bool);
    bool usrUseDefaults(bool);
    void usrSetDefaults();
    void usrRead();
    bool usrSave();
    void usrReadConfig();
    bool usrWriteConfig();

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipKConfigSkeleton(const sipKConfigSkeleton &);
    sipKConfigSkeleton &operator = (const sipKConfigSkeleton &);

    char sipPyMethods[15];
};

sipKConfigSkeleton::sipKConfigSkeleton(const  ::QString& a0, ::QObject*a1):  ::KConfigSkeleton(a0,a1), sipPySelf(0)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipKConfigSkeleton::~sipKConfigSkeleton()
{
    sipInstanceDestroyed(sipPySelf);
}

const QMetaObject *sipKConfigSkeleton::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_KConfigGui_qt_metaobject(sipPySelf,sipType_KConfigSkeleton);

    return  ::KConfigSkeleton::metaObject();
}

int sipKConfigSkeleton::qt_metacall(QMetaObject::Call _c,int _id,void **_a)
{
    _id =  ::KConfigSkeleton::qt_metacall(_c,_id,_a);

    if (_id >= 0)
        _id = sip_KConfigGui_qt_metacall(sipPySelf,sipType_KConfigSkeleton,_c,_id,_a);

    return _id;
}

void *sipKConfigSkeleton::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_KConfigGui_qt_metacast(sipPySelf, sipType_KConfigSkeleton, _clname, &sipCpp) ? sipCpp :  ::KConfigSkeleton::qt_metacast(_clname));
}

void sipKConfigSkeleton::disconnectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[0],sipPySelf,NULL,sipName_disconnectNotify);

    if (!sipMeth)
    {
         ::KConfigSkeleton::disconnectNotify(a0);
        return;
    }

    extern void sipVH_KConfigGui_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_KConfigGui_8(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeleton::connectNotify(const  ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[1],sipPySelf,NULL,sipName_connectNotify);

    if (!sipMeth)
    {
         ::KConfigSkeleton::connectNotify(a0);
        return;
    }

    extern void sipVH_KConfigGui_8(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const  ::QMetaMethod&);

    sipVH_KConfigGui_8(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeleton::customEvent( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[2],sipPySelf,NULL,sipName_customEvent);

    if (!sipMeth)
    {
         ::KConfigSkeleton::customEvent(a0);
        return;
    }

    extern void sipVH_KConfigGui_7(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    sipVH_KConfigGui_7(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeleton::childEvent( ::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[3],sipPySelf,NULL,sipName_childEvent);

    if (!sipMeth)
    {
         ::KConfigSkeleton::childEvent(a0);
        return;
    }

    extern void sipVH_KConfigGui_6(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QChildEvent*);

    sipVH_KConfigGui_6(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeleton::timerEvent( ::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[4],sipPySelf,NULL,sipName_timerEvent);

    if (!sipMeth)
    {
         ::KConfigSkeleton::timerEvent(a0);
        return;
    }

    extern void sipVH_KConfigGui_5(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QTimerEvent*);

    sipVH_KConfigGui_5(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipKConfigSkeleton::eventFilter( ::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[5],sipPySelf,NULL,sipName_eventFilter);

    if (!sipMeth)
        return  ::KConfigSkeleton::eventFilter(a0,a1);

    extern bool sipVH_KConfigGui_4(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QObject*, ::QEvent*);

    return sipVH_KConfigGui_4(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipKConfigSkeleton::event( ::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[6],sipPySelf,NULL,sipName_event);

    if (!sipMeth)
        return  ::KConfigSkeleton::event(a0);

    extern bool sipVH_KConfigGui_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *,  ::QEvent*);

    return sipVH_KConfigGui_3(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeleton::setDefaults()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[7],sipPySelf,NULL,sipName_setDefaults);

    if (!sipMeth)
    {
         ::KConfigSkeleton::setDefaults();
        return;
    }

    extern void sipVH_KConfigGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigGui_1(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKConfigSkeleton::useDefaults(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[8],sipPySelf,NULL,sipName_useDefaults);

    if (!sipMeth)
        return  ::KConfigSkeleton::useDefaults(a0);

    extern bool sipVH_KConfigGui_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_KConfigGui_2(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipKConfigSkeleton::usrUseDefaults(bool a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[9],sipPySelf,NULL,sipName_usrUseDefaults);

    if (!sipMeth)
        return  ::KConfigSkeleton::usrUseDefaults(a0);

    extern bool sipVH_KConfigGui_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, bool);

    return sipVH_KConfigGui_2(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipKConfigSkeleton::usrSetDefaults()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[10],sipPySelf,NULL,sipName_usrSetDefaults);

    if (!sipMeth)
    {
         ::KConfigSkeleton::usrSetDefaults();
        return;
    }

    extern void sipVH_KConfigGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigGui_1(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipKConfigSkeleton::usrRead()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[11],sipPySelf,NULL,sipName_usrRead);

    if (!sipMeth)
    {
         ::KConfigSkeleton::usrRead();
        return;
    }

    extern void sipVH_KConfigGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigGui_1(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKConfigSkeleton::usrSave()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[12],sipPySelf,NULL,sipName_usrSave);

    if (!sipMeth)
        return  ::KConfigSkeleton::usrSave();

    extern bool sipVH_KConfigGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigGui_0(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

void sipKConfigSkeleton::usrReadConfig()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[13],sipPySelf,NULL,sipName_usrReadConfig);

    if (!sipMeth)
    {
         ::KConfigSkeleton::usrReadConfig();
        return;
    }

    extern void sipVH_KConfigGui_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_KConfigGui_1(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipKConfigSkeleton::usrWriteConfig()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState,&sipPyMethods[14],sipPySelf,NULL,sipName_usrWriteConfig);

    if (!sipMeth)
        return  ::KConfigSkeleton::usrWriteConfig();

    extern bool sipVH_KConfigGui_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_KConfigGui_0(sipGILState, sipImportedVirtErrorHandlers_KConfigGui_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

 ::QObject* sipKConfigSkeleton::sipProtect_sender() const
{
    return  ::QObject::sender();
}

int sipKConfigSkeleton::sipProtect_receivers(const char*a0) const
{
    return  ::QObject::receivers(a0);
}

void sipKConfigSkeleton::sipProtectVirt_timerEvent(bool sipSelfWasArg, ::QTimerEvent*a0)
{
    (sipSelfWasArg ?  ::QObject::timerEvent(a0) : timerEvent(a0));
}

void sipKConfigSkeleton::sipProtectVirt_childEvent(bool sipSelfWasArg, ::QChildEvent*a0)
{
    (sipSelfWasArg ?  ::QObject::childEvent(a0) : childEvent(a0));
}

void sipKConfigSkeleton::sipProtectVirt_customEvent(bool sipSelfWasArg, ::QEvent*a0)
{
    (sipSelfWasArg ?  ::QObject::customEvent(a0) : customEvent(a0));
}

void sipKConfigSkeleton::sipProtectVirt_connectNotify(bool sipSelfWasArg,const  ::QMetaMethod& a0)
{
    (sipSelfWasArg ?  ::QObject::connectNotify(a0) : connectNotify(a0));
}

void sipKConfigSkeleton::sipProtectVirt_disconnectNotify(bool sipSelfWasArg,const  ::QMetaMethod& a0)
{
    (sipSelfWasArg ?  ::QObject::disconnectNotify(a0) : disconnectNotify(a0));
}

int sipKConfigSkeleton::sipProtect_senderSignalIndex() const
{
    return  ::QObject::senderSignalIndex();
}

bool sipKConfigSkeleton::sipProtect_isSignalConnected(const  ::QMetaMethod& a0) const
{
    return  ::QObject::isSignalConnected(a0);
}

bool sipKConfigSkeleton::sipProtectVirt_usrUseDefaults(bool sipSelfWasArg,bool a0)
{
    return (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrUseDefaults(a0) : usrUseDefaults(a0));
}

void sipKConfigSkeleton::sipProtectVirt_usrSetDefaults(bool sipSelfWasArg)
{
    (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrSetDefaults() : usrSetDefaults());
}

void sipKConfigSkeleton::sipProtectVirt_usrRead(bool sipSelfWasArg)
{
    (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrRead() : usrRead());
}

bool sipKConfigSkeleton::sipProtectVirt_usrSave(bool sipSelfWasArg)
{
    return (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrSave() : usrSave());
}

void sipKConfigSkeleton::sipProtectVirt_usrReadConfig(bool sipSelfWasArg)
{
    (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrReadConfig() : usrReadConfig());
}

bool sipKConfigSkeleton::sipProtectVirt_usrWriteConfig(bool sipSelfWasArg)
{
    return (sipSelfWasArg ?  ::KCoreConfigSkeleton::usrWriteConfig() : usrWriteConfig());
}


extern "C" {static PyObject *meth_KConfigSkeleton_sender(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_sender(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        const sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KConfigSkeleton, &sipCpp))
        {
             ::QObject*sipRes = 0;

        // sender() must be called without the GIL to avoid possible deadlocks between
        // the GIL and Qt's internal thread data mutex.
        
        Py_BEGIN_ALLOW_THREADS
        
        #if defined(SIP_PROTECTED_IS_PUBLIC)
        sipRes = sipCpp->sender();
        #else
        sipRes = sipCpp->sipProtect_sender();
        #endif
        
        Py_END_ALLOW_THREADS
        
        if (!sipRes)
        {
            typedef QObject *(*qtcore_qobject_sender_t)();
        
            static qtcore_qobject_sender_t qtcore_qobject_sender = 0;
        
            if (!qtcore_qobject_sender)
            {
                qtcore_qobject_sender = (qtcore_qobject_sender_t)sipImportSymbol("qtcore_qobject_sender");
                Q_ASSERT(qtcore_qobject_sender);
            }
        
            sipRes = qtcore_qobject_sender();
        }

            return sipConvertFromType(sipRes,sipType_QObject,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_sender, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_receivers(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_receivers(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        PyObject * a0;
        const sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BP0", &sipSelf, sipType_KConfigSkeleton, &sipCpp, &a0))
        {
            int sipRes = 0;
            sipErrorState sipError = sipErrorNone;

        // We need to handle the signal object.  Import the helper if it hasn't already
        // been done.
        typedef sipErrorState (*pyqt5_get_signal_signature_t)(PyObject *, const QObject *, const QByteArray &);
        
        static pyqt5_get_signal_signature_t pyqt5_get_signal_signature = 0;
        
        if (!pyqt5_get_signal_signature)
        {
            pyqt5_get_signal_signature = (pyqt5_get_signal_signature_t)sipImportSymbol("pyqt5_get_signal_signature");
            Q_ASSERT(pyqt5_get_signal_signature);
        }
        
        QByteArray signal_signature;
            
        #if defined(SIP_PROTECTED_IS_PUBLIC)
        if ((sipError = pyqt5_get_signal_signature(a0, sipCpp, signal_signature)) == sipErrorNone)
        {
            sipRes = sipCpp->receivers(signal_signature.constData());
        }
        #else
        if ((sipError = pyqt5_get_signal_signature(a0, static_cast<const QObject *>(sipCpp), signal_signature)) == sipErrorNone)
        {
            sipRes = sipCpp->sipProtect_receivers(signal_signature.constData());
        }
        #endif
        else if (sipError == sipErrorContinue)
        {
            sipError = sipBadCallableArg(0, a0);
        }

            if (sipError == sipErrorFail)
                return 0;

            if (sipError == sipErrorNone)
            {
            return SIPLong_FromLong(sipRes);
            }

            sipAddException(sipError, &sipParseErr);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_receivers, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_timerEvent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_timerEvent(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QTimerEvent* a0;
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ8", &sipSelf, sipType_KConfigSkeleton, &sipCpp, sipType_QTimerEvent, &a0))
        {
            sipCpp->sipProtectVirt_timerEvent(sipSelfWasArg,a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_timerEvent, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_childEvent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_childEvent(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QChildEvent* a0;
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ8", &sipSelf, sipType_KConfigSkeleton, &sipCpp, sipType_QChildEvent, &a0))
        {
            sipCpp->sipProtectVirt_childEvent(sipSelfWasArg,a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_childEvent, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_customEvent(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_customEvent(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
         ::QEvent* a0;
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ8", &sipSelf, sipType_KConfigSkeleton, &sipCpp, sipType_QEvent, &a0))
        {
            sipCpp->sipProtectVirt_customEvent(sipSelfWasArg,a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_customEvent, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_connectNotify(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_connectNotify(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QMetaMethod* a0;
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ9", &sipSelf, sipType_KConfigSkeleton, &sipCpp, sipType_QMetaMethod, &a0))
        {
            sipCpp->sipProtectVirt_connectNotify(sipSelfWasArg,*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_connectNotify, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_disconnectNotify(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_disconnectNotify(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const  ::QMetaMethod* a0;
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ9", &sipSelf, sipType_KConfigSkeleton, &sipCpp, sipType_QMetaMethod, &a0))
        {
            sipCpp->sipProtectVirt_disconnectNotify(sipSelfWasArg,*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_disconnectNotify, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_senderSignalIndex(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_senderSignalIndex(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        const sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KConfigSkeleton, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->sipProtect_senderSignalIndex();

            return SIPLong_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_senderSignalIndex, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_isSignalConnected(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_isSignalConnected(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QMetaMethod* a0;
        const sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "BJ9", &sipSelf, sipType_KConfigSkeleton, &sipCpp, sipType_QMetaMethod, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtect_isSignalConnected(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_isSignalConnected, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_usrUseDefaults(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_usrUseDefaults(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        bool a0;
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "Bb", &sipSelf, sipType_KConfigSkeleton, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtectVirt_usrUseDefaults(sipSelfWasArg,a0);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_usrUseDefaults, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_usrSetDefaults(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_usrSetDefaults(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KConfigSkeleton, &sipCpp))
        {
            sipCpp->sipProtectVirt_usrSetDefaults(sipSelfWasArg);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_usrSetDefaults, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_usrRead(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_usrRead(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KConfigSkeleton, &sipCpp))
        {
            sipCpp->sipProtectVirt_usrRead(sipSelfWasArg);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_usrRead, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_usrSave(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_usrSave(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KConfigSkeleton, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtectVirt_usrSave(sipSelfWasArg);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_usrSave, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_usrReadConfig(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_usrReadConfig(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KConfigSkeleton, &sipCpp))
        {
            sipCpp->sipProtectVirt_usrReadConfig(sipSelfWasArg);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_usrReadConfig, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_usrWriteConfig(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_usrWriteConfig(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = NULL;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        sipKConfigSkeleton *sipCpp;

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, NULL, NULL, "B", &sipSelf, sipType_KConfigSkeleton, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->sipProtectVirt_usrWriteConfig(sipSelfWasArg);

            return PyBool_FromLong(sipRes);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_usrWriteConfig, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_addItemColor(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_addItemColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QColor* a1;
        int a1State = 0;
        const  ::QColor& a2def = QColor(128,128,128);
        const  ::QColor* a2 = &a2def;
        int a2State = 0;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1|J1J1", &sipSelf, sipType_KConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QColor, &a1, &a1State, sipType_QColor, &a2, &a2State, sipType_QString,&a3, &a3State))
        {
             ::KConfigSkeleton::ItemColor*sipRes;

            sipRes = sipCpp->addItemColor(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(a1,sipType_QColor,a1State);
            sipReleaseType(const_cast< ::QColor *>(a2),sipType_QColor,a2State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KConfigSkeleton_ItemColor,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_addItemColor, NULL);

    return NULL;
}


extern "C" {static PyObject *meth_KConfigSkeleton_addItemFont(PyObject *, PyObject *);}
static PyObject *meth_KConfigSkeleton_addItemFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = NULL;

    {
        const  ::QString* a0;
        int a0State = 0;
         ::QFont* a1;
        const  ::QFont& a2def = QFont();
        const  ::QFont* a2 = &a2def;
        const  ::QString& a3def = QString();
        const  ::QString* a3 = &a3def;
        int a3State = 0;
         ::KConfigSkeleton *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J9|J9J1", &sipSelf, sipType_KConfigSkeleton, &sipCpp, sipType_QString,&a0, &a0State, sipType_QFont, &a1, sipType_QFont, &a2, sipType_QString,&a3, &a3State))
        {
             ::KConfigSkeleton::ItemFont*sipRes;

            sipRes = sipCpp->addItemFont(*a0,*a1,*a2,*a3);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);
            sipReleaseType(const_cast< ::QString *>(a3),sipType_QString,a3State);

            return sipConvertFromType(sipRes,sipType_KConfigSkeleton_ItemFont,NULL);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoMethod(sipParseErr, sipName_KConfigSkeleton, sipName_addItemFont, NULL);

    return NULL;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_KConfigSkeleton(void *, const sipTypeDef *);}
static void *cast_KConfigSkeleton(void *sipCppV, const sipTypeDef *targetType)
{
     ::KConfigSkeleton *sipCpp = reinterpret_cast< ::KConfigSkeleton *>(sipCppV);

    if (targetType == sipType_KCoreConfigSkeleton)
        return static_cast< ::KCoreConfigSkeleton *>(sipCpp);

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return sipCppV;
}


/* Call the instance's destructor. */
extern "C" {static void release_KConfigSkeleton(void *, int);}
static void release_KConfigSkeleton(void *sipCppV, int)
{
     ::KConfigSkeleton *sipCpp = reinterpret_cast< ::KConfigSkeleton *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_KConfigSkeleton(sipSimpleWrapper *);}
static void dealloc_KConfigSkeleton(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipKConfigSkeleton *>(sipGetAddress(sipSelf))->sipPySelf = NULL;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_KConfigSkeleton(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_KConfigSkeleton(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_KConfigSkeleton(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipKConfigSkeleton *sipCpp = 0;

    {
        const  ::QString& a0def = QString();
        const  ::QString* a0 = &a0def;
        int a0State = 0;
         ::QObject* a1 = nullptr;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, NULL, sipUnused, "|J1JH", sipType_QString,&a0, &a0State, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipKConfigSkeleton(*a0,a1);
            sipReleaseType(const_cast< ::QString *>(a0),sipType_QString,a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return NULL;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_KConfigSkeleton[] = {{4, 1, 1}};


static PyMethodDef methods_KConfigSkeleton[] = {
    {SIP_MLNAME_CAST(sipName_addItemColor), meth_KConfigSkeleton_addItemColor, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_addItemFont), meth_KConfigSkeleton_addItemFont, METH_VARARGS, NULL},
    {SIP_MLNAME_CAST(sipName_childEvent), (PyCFunction)meth_KConfigSkeleton_childEvent, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_connectNotify), (PyCFunction)meth_KConfigSkeleton_connectNotify, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_customEvent), (PyCFunction)meth_KConfigSkeleton_customEvent, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_disconnectNotify), (PyCFunction)meth_KConfigSkeleton_disconnectNotify, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_isSignalConnected), (PyCFunction)meth_KConfigSkeleton_isSignalConnected, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_receivers), (PyCFunction)meth_KConfigSkeleton_receivers, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_sender), (PyCFunction)meth_KConfigSkeleton_sender, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_senderSignalIndex), (PyCFunction)meth_KConfigSkeleton_senderSignalIndex, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_timerEvent), (PyCFunction)meth_KConfigSkeleton_timerEvent, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrRead), (PyCFunction)meth_KConfigSkeleton_usrRead, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrReadConfig), (PyCFunction)meth_KConfigSkeleton_usrReadConfig, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrSave), (PyCFunction)meth_KConfigSkeleton_usrSave, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrSetDefaults), (PyCFunction)meth_KConfigSkeleton_usrSetDefaults, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrUseDefaults), (PyCFunction)meth_KConfigSkeleton_usrUseDefaults, METH_VARARGS|METH_KEYWORDS, NULL},
    {SIP_MLNAME_CAST(sipName_usrWriteConfig), (PyCFunction)meth_KConfigSkeleton_usrWriteConfig, METH_VARARGS|METH_KEYWORDS, NULL}
};


static pyqt5ClassPluginDef plugin_KConfigSkeleton = {
    & ::KConfigSkeleton::staticMetaObject,
    0,
    0,
    0
};


sipClassTypeDef sipTypeDef_KConfigGui_KConfigSkeleton = {
    {
        -1,
        0,
        0,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_CLASS,
        sipNameNr_KConfigSkeleton,
        {0},
        &plugin_KConfigSkeleton
    },
    {
        sipNameNr_KConfigSkeleton,
        {0, 0, 1},
        17, methods_KConfigSkeleton,
        0, 0,
        0, 0,
        {0, 0, 0, 0, 0, 0, 0, 0, 0, 0},
    },
    0,
    -1,
    -1,
    supers_KConfigSkeleton,
    0,
    init_type_KConfigSkeleton,
    0,
    0,
#if PY_MAJOR_VERSION >= 3
    0,
    0,
#else
    0,
    0,
    0,
    0,
#endif
    dealloc_KConfigSkeleton,
    0,
    0,
    0,
    release_KConfigSkeleton,
    cast_KConfigSkeleton,
    0,
    0,
    0,
    0,
    0,
    0
};
